<?php

/**
 * @file
 * Contains \Drupal\Tests\Core\PageCache\NoSessionOpenTest.
 */

namespace Drupal\Tests\Core\PageCache;

use Drupal\Core\PageCache\RequestPolicyInterface;
use Drupal\Core\PageCache\RequestPolicy;
use Drupal\Tests\UnitTestCase;
use Symfony\Component\HttpFoundation\Request;

/**
 * @coversDefaultClass \Drupal\Core\PageCache\RequestPolicy\NoSessionOpen
 * @group PageCache
 */
class NoSessionOpenTest extends UnitTestCase {

  /**
   * The session cookie name.
   *
   * @var string
   */
  protected $sessionCookieName;

  /**
   * The request policy under test.
   *
   * @var \Drupal\Core\PageCache\RequestPolicy\NoSessionOpen
   */
  protected $policy;

  public function setUp() {
    $this->sessionCookieName = 'B1ESkdf3V4F8u27myaSAShuuHc';
    $this->policy = new RequestPolicy\NoSessionOpen($this->sessionCookieName);
  }

  /**
   * Asserts that caching is allowed unless there is a session cookie present.
   *
   * @covers ::check
   */
  public function testNoAllowUnlessSessionCookiePresent() {
    $request = new Request();
    $result = $this->policy->check($request);
    $this->assertSame(RequestPolicyInterface::ALLOW, $result);

    $request = Request::create('/', 'GET', [], [$this->sessionCookieName => 'some-session-id']);
    $result = $this->policy->check($request);
    $this->assertSame(NULL, $result);
  }
}
